% viewSim(logfilename)
%
% Reads the log output of the AVR Studio simulator.
% Intended to parse the log of ATTINY2313 PortD data
% which is the IR transmitter signal.
%
function viewSim(filename)

freq=4e6;
%tvals=[0]; bvals=[0];
tvals=[]; bvals=[];

%% parse "tick:value" pairs from the file
fd=fopen(filename,'r');
while 1,
    txt = fgetl(fd);
    if ~ischar(txt), break, end
    % disp(txt)
    txt(10) = ' '; % replace the semicolon
    [combo]=sscanf(txt,'%d %02d');
    tvals = [tvals; combo(1)];
    bvals = [bvals; combo(2)];
end
fclose(fd);

%% show first modulation periods
for i=1:4,
   dT=(tvals(i+1)-tvals(i))*1e6/freq;
   if(bvals(i)==0),
       fprintf(1,'Period OFF %f usec\n', dT);
   else
       fprintf(1,'Period ON %f usec\n', dT);
   end
end

%% thinning
tvals = tvals(1:2:max(size(tvals)));
bvals = bvals(1:2:max(size(bvals)));

%% plot
figure(1),stem(tvals.*(1e6/freq), bvals), xlabel('usec'), ylabel('value');

%% find delta-Ts after modulation
maxStep=2*60;
prevEdgeT=0;
for i=1:(max(size(bvals))-1),
    currStep = tvals(i+1)-tvals(i);
    if (currStep>maxStep),
       nT=tvals(i)*1e6/freq;
       dT=currStep*1e6/freq;
       fprintf(1,'Rising edge at %f usec length %f, delta %f\n', nT,dT,nT-prevEdgeT);
       prevEdgeT=nT;
    end
end
